<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
 xmlns:stsuuser="urn:ibm:names:ITFIM:1.0:stsuuser" version="1.0" xmlns:fc="urn:ibm:names:ITFIM:1.0:Federations" xmlns:fim="urn:ibm:names:ITFIM:1.0">
 <xsl:strip-space elements="*" />
 <xsl:output method="text" encoding="utf-8" />

 <xsl:param name="fedName" />
 <xsl:param name="encryptionKeystore" />
 <xsl:param name="encryptionKeyLabel" />
 <xsl:param name="signingKeystore" />
 <xsl:param name="signingKeyLabel" />
 <xsl:param name="validationKeystore" />
 <xsl:param name="validationKeyLabel" />
 <xsl:param name="reverseProxyInstance" />
 <xsl:param name="aacUsername" />
 <xsl:param name="aacPwd" />

 <xsl:template match="*">
   <xsl:apply-templates select="/fc:FederationsConfiguration/fc:EntityGroups/fc:EntityGroup[fc:DisplayName = $fedName]" />
 </xsl:template>

 <xsl:template match="fc:EntityGroup" >
  <xsl:variable name="selfEntityRef"><xsl:value-of select="fc:Self/@entityRef" /></xsl:variable>
  <xsl:text>- name: Configure Federation Migrated from FIM</xsl:text>
  <xsl:text>&#10;  hosts: all</xsl:text>
  <xsl:text>&#10;  connection: local</xsl:text>
  <xsl:text>&#10;  roles:</xsl:text>
  <xsl:text>&#10;      - role: set_federation</xsl:text>
  <xsl:text>&#10;        tags: ["federation", "migrate"]</xsl:text>
  <xsl:text>&#10;        set_federation_name: "</xsl:text><xsl:value-of select="fc:DisplayName" /><xsl:text>"</xsl:text>
  <xsl:text>&#10;        set_federation_protocol: "</xsl:text><xsl:value-of select="fc:Self/fc:EntityProperty[@name='FED_PROT']/fim:Value" /><xsl:text>"</xsl:text>
  <xsl:text>&#10;        set_federation_role: "</xsl:text><xsl:value-of select="/fc:FederationsConfiguration/fc:Entities/fc:Entity[@id=$selfEntityRef]/@role" /><xsl:text>"</xsl:text>
  <xsl:text>&#10;        set_federation_templateName: ""</xsl:text>
  <xsl:text>&#10;        set_federation_configuration:</xsl:text>
  <xsl:text>&#10;          artifactLifeTime: </xsl:text><xsl:value-of select="fc:Self/fc:EntityProperty[@name='SAML2.ArtifactLifeTime']/fim:Value" />
  <xsl:text>&#10;          assertionSettings:</xsl:text>
  <xsl:text>&#10;            assertionValidAfter: </xsl:text><xsl:value-of select="fc:Self/fc:EntityProperty[@name='com.tivoli.am.fim.sts.saml.2.0.assertion.posttime.valid']/fim:Value" />
  <xsl:text>&#10;            assertionValidBefore: </xsl:text><xsl:value-of select="fc:Self/fc:EntityProperty[@name='com.tivoli.am.fim.sts.saml.2.0.assertion.pretime.valid']/fim:Value" />
  <xsl:text>&#10;          companyName: "</xsl:text><xsl:value-of select="/fc:FederationsConfiguration/fc:Entities/fc:Entity[@id=$selfEntityRef]/fc:DisplayName" /><xsl:text>"</xsl:text>
  <xsl:text>&#10;          encryptionSettings:</xsl:text>
  <xsl:text>&#10;            decryptionKeyIdentifier:</xsl:text>
  <xsl:text>&#10;              keystore: "</xsl:text><xsl:value-of select="$encryptionKeystore" /><xsl:text>"</xsl:text>
  <xsl:text>&#10;              label: "</xsl:text><xsl:value-of select="$encryptionKeyLabel" /><xsl:text>"</xsl:text>
  <xsl:text>&#10;          identityMapping:</xsl:text>
  <xsl:text>&#10;            activeDelegateId: "skip-identity-map"</xsl:text>
  <xsl:text>&#10;          messageValidTime: </xsl:text><xsl:value-of select="fc:Self/fc:EntityProperty[@name='SAML2.MessageValidTime']/fim:Value" />
  <xsl:text>&#10;          nameIDFormat:</xsl:text>
  <xsl:text>&#10;            default: </xsl:text><xsl:value-of select="fc:Self/fc:EntityProperty[@name='SAML2.DefaultNameIDFormat']/fim:Value" />
  <xsl:text>&#10;          needConsentToFederate: "</xsl:text><xsl:value-of select="fc:Self/fc:EntityProperty[@name='SAML2.PresentFederationConsent']/fim:Value" /><xsl:text>"</xsl:text>
  <xsl:text>&#10;          pointOfContactUrl: "</xsl:text><xsl:value-of select="fc:Self/fc:EntityProperty[@name='SPS.SelfPathToSPS']/fim:Value" /><xsl:text>"</xsl:text>
  <xsl:text>&#10;          sessionTimeout: </xsl:text><xsl:value-of select="fc:Self/fc:EntityProperty[@name='SAML2.SessionTimeout']/fim:Value" />
  <xsl:text>&#10;          signatureSettings:</xsl:text>
  <xsl:text>&#10;            keyInfoElements:</xsl:text>
  <xsl:text>&#10;              includePublicKey: "</xsl:text><xsl:apply-templates select="fc:Self/fc:EntityProperty[@name='SAML2.IncludePublicKey']/fim:Value"><xsl:with-param name="defaultVal">false</xsl:with-param></xsl:apply-templates><xsl:text>"</xsl:text>
  <xsl:text>&#10;              includeX509CertificateData: "</xsl:text><xsl:apply-templates select="fc:Self/fc:EntityProperty[@name='SAML2.IncludeX509CertificateData']/fim:Value"><xsl:with-param name="defaultVal">true</xsl:with-param></xsl:apply-templates><xsl:text>"</xsl:text>
  <xsl:text>&#10;              includeX509IssuerDetails: "</xsl:text><xsl:apply-templates select="fc:Self/fc:EntityProperty[@name='SAML2.IncludeX509IssuerDetails']/fim:Value"><xsl:with-param name="defaultVal">false</xsl:with-param></xsl:apply-templates><xsl:text>"</xsl:text>
  <xsl:text>&#10;              includeX509SubjectKeyIdentifier: "</xsl:text><xsl:apply-templates select="fc:Self/fc:EntityProperty[@name='SAML2.IncludeX509SubjectKeyIdentifier']/fim:Value"><xsl:with-param name="defaultVal">false</xsl:with-param></xsl:apply-templates><xsl:text>"</xsl:text>
  <xsl:text>&#10;              includeX509SubjectName: "</xsl:text><xsl:apply-templates select="fc:Self/fc:EntityProperty[@name='SAML2.IncludeX509SubjectName']/fim:Value"><xsl:with-param name="defaultVal">false</xsl:with-param></xsl:apply-templates><xsl:text>"</xsl:text>
  <xsl:text>&#10;            signingKeyIdentifier:</xsl:text>
  <xsl:text>&#10;              keystore: "</xsl:text><xsl:value-of select="$signingKeystore" /><xsl:text>"</xsl:text>
  <xsl:text>&#10;              label: "</xsl:text><xsl:value-of select="$signingKeyLabel" /><xsl:text>"</xsl:text>
  <xsl:text>&#10;            signingOptions:</xsl:text>
  <xsl:text>&#10;              signArtifactRequest: "</xsl:text><xsl:value-of select="fc:Self/fc:EntityProperty[@name='SAML2.SignArtifactRequest']/fim:Value" /><xsl:text>"</xsl:text>
  <xsl:text>&#10;              signArtifactResponse: "</xsl:text><xsl:value-of select="fc:Self/fc:EntityProperty[@name='SAML2.SignArtifactResponse']/fim:Value" /><xsl:text>"</xsl:text>
  <xsl:text>&#10;              signAuthnResponse: "</xsl:text><xsl:value-of select="fc:Self/fc:EntityProperty[@name='SAML2.SignAuthnResponse']/fim:Value" /><xsl:text>"</xsl:text>
  <xsl:text>&#10;              signLogoutRequest: "</xsl:text><xsl:value-of select="fc:Self/fc:EntityProperty[@name='SAML2.SignLogoutRequest']/fim:Value" /><xsl:text>"</xsl:text>
  <xsl:text>&#10;              signLogoutResponse: "</xsl:text><xsl:value-of select="fc:Self/fc:EntityProperty[@name='SAML2.SignLogoutResponse']/fim:Value" /><xsl:text>"</xsl:text>
  <xsl:text>&#10;            validationOptions:</xsl:text>
  <xsl:text>&#10;              validateAuthnRequest: "</xsl:text><xsl:value-of select="fc:Self/fc:EntityProperty[@name='SAML2.ValidateAuthnRequest']/fim:Value" /><xsl:text>"</xsl:text>
   <xsl:apply-templates select="/fc:FederationsConfiguration/fc:Entities/fc:Entity[@id=$selfEntityRef]/fc:ProtocolEndpoints/fc:ProtocolEndpoint[@type='SAML2.ArtifactResolutionService']" />
   <xsl:apply-templates select="/fc:FederationsConfiguration/fc:Entities/fc:Entity[@id=$selfEntityRef]/fc:ProtocolEndpoints/fc:ProtocolEndpoint[@type='SAML2.AssertionConsumerService']" />
   <xsl:apply-templates select="/fc:FederationsConfiguration/fc:Entities/fc:Entity[@id=$selfEntityRef]/fc:ProtocolEndpoints/fc:ProtocolEndpoint[@type='SAML2.SingleSignOnService']" />
   <xsl:apply-templates select="/fc:FederationsConfiguration/fc:Entities/fc:Entity[@id=$selfEntityRef]/fc:ProtocolEndpoints/fc:ProtocolEndpoint[@type='SAML2.SingleLogoutService']" />
   <xsl:apply-templates select="/fc:FederationsConfiguration/fc:Entities/fc:Entity[@id=$selfEntityRef]/fc:ProtocolEndpoints/fc:ProtocolEndpoint[@type='SAML2.ManageNameIDService']" />
  <xsl:text>&#10;</xsl:text>
  <xsl:text>&#10;      - role: config_reverseproxy_federation</xsl:text>
  <xsl:text>&#10;        tags: ["federation", "migrate", "reverseproxy", "config"]</xsl:text>
  <xsl:text>&#10;        config_reverseproxy_federation_name: "</xsl:text><xsl:value-of select="$fedName" /><xsl:text>"</xsl:text>
  <xsl:text>&#10;        config_reverseproxy_federation_instance_id: "</xsl:text><xsl:value-of select="$reverseProxyInstance" /><xsl:text>"</xsl:text>
  <xsl:text>&#10;        config_reverseproxy_federation_username: "</xsl:text><xsl:value-of select="$aacUsername" /><xsl:text>"</xsl:text>
  <xsl:text>&#10;        config_reverseproxy_federation_password: "</xsl:text><xsl:value-of select="$aacPwd" /><xsl:text>"</xsl:text>
  <xsl:text>&#10;</xsl:text>
   <xsl:apply-templates select="fc:Partners/fc:Partner" />
 </xsl:template>

 <xsl:template match="fim:Value">
   <xsl:param name="defaultVal" />
   <xsl:choose>
     <xsl:when test=". = 'true'">
       <xsl:text>true</xsl:text>
     </xsl:when>
     <xsl:when test=". = 'false'">
       <xsl:text>false</xsl:text>
     </xsl:when>
     <xsl:otherwise><xsl:value-of select="$defaultVal" /></xsl:otherwise>
   </xsl:choose>
 </xsl:template>

 <xsl:template match="fc:ProtocolEndpoint[@type='SAML2.ArtifactResolutionService']">
  <xsl:if test="position() = 1">
    <xsl:text>&#10;          artifactResolutionService: [ </xsl:text>
  </xsl:if>
  <xsl:text>{ </xsl:text>
  <xsl:apply-templates select="fc:EndpointProperties/fim:Parameter[@name='Binding']" />
  <xsl:apply-templates select="fc:EndpointProperties/fim:Parameter[@name='IsDefault']" />
  <xsl:apply-templates select="fc:EndpointProperties/fim:Parameter[@name='Index']" />
  <xsl:text>, "url": "</xsl:text><xsl:value-of select="@endpoint" /><xsl:text>"</xsl:text>
  <xsl:text> }</xsl:text>
  <xsl:choose>
   <xsl:when test="position() = last()">
     <xsl:text> ]</xsl:text>
   </xsl:when>
   <xsl:otherwise>
     <xsl:text>, </xsl:text>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <xsl:template match="fc:ProtocolEndpoint[@type='SAML2.AssertionConsumerService']">
  <xsl:if test="position() = 1">
    <xsl:text>&#10;          assertionConsumerService: [ </xsl:text>
  </xsl:if>
  <xsl:text>{ </xsl:text>
  <xsl:apply-templates select="fc:EndpointProperties/fim:Parameter[@name='Binding']" />
  <xsl:apply-templates select="fc:EndpointProperties/fim:Parameter[@name='IsDefault']" />
  <xsl:apply-templates select="fc:EndpointProperties/fim:Parameter[@name='Index']" />
  <xsl:text>, "url": "</xsl:text><xsl:value-of select="@endpoint" /><xsl:text>"</xsl:text>
  <xsl:text> }</xsl:text>
  <xsl:choose>
   <xsl:when test="position() = last()">
     <xsl:text> ]</xsl:text>
   </xsl:when>
   <xsl:otherwise>
     <xsl:text>, </xsl:text>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <xsl:template match="fc:ProtocolEndpoint[@type='SAML2.SingleSignOnService']">
  <xsl:if test="position() = 1">
    <xsl:text>&#10;          singleSignOnService: [ </xsl:text>
  </xsl:if>
  <xsl:text>{ </xsl:text>
  <xsl:apply-templates select="fc:EndpointProperties/fim:Parameter[@name='Binding']" />
  <xsl:text>, "url": "</xsl:text><xsl:value-of select="@endpoint" /><xsl:text>"</xsl:text>
  <xsl:text> }</xsl:text>
  <xsl:choose>
   <xsl:when test="position() = last()">
     <xsl:text> ]</xsl:text>
   </xsl:when>
   <xsl:otherwise>
     <xsl:text>, </xsl:text>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <xsl:template match="fc:ProtocolEndpoint[@type='SAML2.SingleLogoutService']">
  <xsl:if test="position() = 1">
    <xsl:text>&#10;          singleLogoutService: [ </xsl:text>
  </xsl:if>
  <xsl:text>{ </xsl:text>
  <xsl:apply-templates select="fc:EndpointProperties/fim:Parameter[@name='Binding']" />
  <xsl:text>, "url": "</xsl:text><xsl:value-of select="@endpoint" /><xsl:text>"</xsl:text>
  <xsl:text> }</xsl:text>
  <xsl:choose>
   <xsl:when test="position() = last()">
     <xsl:text> ]</xsl:text>
   </xsl:when>
   <xsl:otherwise>
     <xsl:text>, </xsl:text>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <xsl:template match="fc:ProtocolEndpoint[@type='SAML2.ManageNameIDService']">
  <xsl:if test="position() = 1">
    <xsl:text>&#10;          manageNameIDService: [ </xsl:text>
  </xsl:if>
  <xsl:text>{ </xsl:text>
  <xsl:apply-templates select="fc:EndpointProperties/fim:Parameter[@name='Binding']" />
  <xsl:text>, "url": "</xsl:text><xsl:value-of select="@endpoint" /><xsl:text>"</xsl:text>
  <xsl:text> }</xsl:text>
  <xsl:choose>
   <xsl:when test="position() = last()">
     <xsl:text> ]</xsl:text>
   </xsl:when>
   <xsl:otherwise>
     <xsl:text>, </xsl:text>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <xsl:template match="fim:Parameter[@name='Binding']">
  <xsl:text>"binding": "</xsl:text>
    <xsl:choose>
    <xsl:when test="fim:Value = 'urn:oasis:names:tc:SAML:2.0:bindings:SOAP'">
      <xsl:text>soap"</xsl:text>
    </xsl:when>
    <xsl:when test="fim:Value = 'urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact'">
      <xsl:text>artifact"</xsl:text>
    </xsl:when>
    <xsl:when test="fim:Value = 'urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST'">
      <xsl:text>post"</xsl:text>
    </xsl:when>
    <xsl:when test="fim:Value = 'urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect'">
      <xsl:text>redirect"</xsl:text>
    </xsl:when>
    <xsl:otherwise>
      <xsl:text>"</xsl:text>
    </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <xsl:template match="fim:Parameter[@name='IsDefault']">
   <xsl:text>, "default": </xsl:text><xsl:value-of select="fim:Value" />
 </xsl:template>

 <xsl:template match="fim:Parameter[@name='Index']">
   <xsl:text>, "index": </xsl:text><xsl:value-of select="fim:Value" />
 </xsl:template>

 <xsl:template match="fc:Partner">
  <xsl:variable name="partnerEntityRef"><xsl:value-of select="@entityRef" /></xsl:variable>
  <xsl:text>&#10;      - role: set_partner</xsl:text>
  <xsl:text>&#10;        tags: ["federation", "partner", "migrate"]</xsl:text>
  <xsl:text>&#10;        set_partner_federation_name: "</xsl:text><xsl:value-of select="$fedName" /><xsl:text>"</xsl:text>
  <xsl:text>&#10;        set_partner_partner_name: "</xsl:text><xsl:value-of select="/fc:FederationsConfiguration/fc:Entities/fc:Entity[@id=$partnerEntityRef]/fc:DisplayName" /><xsl:text>"</xsl:text>
  <xsl:text>&#10;        set_partner_enabled: </xsl:text><xsl:call-template name="getStateBooleanText"><xsl:with-param name="state" select="@state" /></xsl:call-template>
  <xsl:text>&#10;        set_partner_role: "</xsl:text><xsl:value-of select="/fc:FederationsConfiguration/fc:Entities/fc:Entity[@id=$partnerEntityRef]/@role" /><xsl:text>"</xsl:text>
  <xsl:text>&#10;        set_partner_templateName: ""</xsl:text>
  <xsl:text>&#10;        set_partner_configuration:</xsl:text>
  <xsl:text>&#10;          assertionSettings:</xsl:text>
  <xsl:text>&#10;            assertionAttributeTypes: [ </xsl:text><xsl:apply-templates select="fc:EntityProperty[@name='com.tivoli.am.fim.sts.saml.2.0.assertion.attribute.types']/fim:Value" /><xsl:text> ]</xsl:text>
  <xsl:text>&#10;            sessionNotOnOrAfter: </xsl:text><xsl:value-of select="fc:EntityProperty[@name='SAML2.SessionNotOnOrAfter']" />
  <xsl:text>&#10;          attributeMapping:</xsl:text>
  <xsl:text>&#10;            map: []</xsl:text>
  <xsl:text>&#10;          encryptionSettings:</xsl:text>
  <xsl:text>&#10;            blockEncryptionAlgorithm: "AES-128"</xsl:text>
  <xsl:text>&#10;            encryptionKeyIdentifier:</xsl:text>
  <xsl:text>&#10;            encryptionKeyTransportAlgorithm: "</xsl:text><xsl:apply-templates select="fc:EntityProperty[@name='SAML2.EncryptionKeyTransportAlgorithm']" /><xsl:text>"</xsl:text>
  <xsl:text>&#10;            encryptionOptions:</xsl:text>
  <xsl:text>&#10;              encryptAssertion: </xsl:text><xsl:value-of select="fc:EntityProperty[@name='SAML2.EncryptAssertions']" />
  <xsl:text>&#10;              encryptAssertionAttributes: </xsl:text><xsl:value-of select="fc:EntityProperty[@name='SAML2.EncryptAllAttributes']" />
  <xsl:text>&#10;              encryptNameID: </xsl:text><xsl:value-of select="fc:EntityProperty[@name='SAML2.EncryptNameIdentifiers']" />
  <xsl:text>&#10;          includeFedIdInAliasPartnerId: </xsl:text><xsl:value-of select="fc:EntityProperty[@name='SAML2.IncludeFedIdInAliasPartnerId']/fim:Value" />
  <xsl:text>&#10;          logoutRequestLifeTime: </xsl:text><xsl:apply-templates select="fc:EntityProperty[@name='SAML2.LogoutNotOnOrAfter']" />
  <xsl:text>&#10;          nameIDFormat:</xsl:text>
  <xsl:text>&#10;            default: </xsl:text><xsl:value-of select="fc:Self/fc:EntityProperty[@name='SAML2.DefaultNameIDFormat']/fim:Value" />
  <xsl:text>&#10;          providerId: "</xsl:text><xsl:value-of select="/fc:FederationsConfiguration/fc:Entities/fc:Entity[@id=$partnerEntityRef]/@protocolId" /><xsl:text>"</xsl:text>
  <xsl:text>&#10;          signatureSettings:</xsl:text>
  <xsl:apply-templates select="fc:EntityProperty[@name='SAML2.SignatureAlgorithm']" />
  <xsl:text>&#10;            signingOptions:</xsl:text>
  <xsl:text>&#10;              signAssertion: </xsl:text><xsl:value-of select="fc:EntityProperty[@name='com.tivoli.am.fim.sts.saml.2.0.assertion.sign']/fim:Value" />
  <xsl:text>&#10;              signAuthnResponse: </xsl:text><xsl:value-of select="fc:EntityProperty[@name='SAML2.SignAuthnResponse']/fim:Value" />
  <xsl:text>&#10;            validationKeyIdentifier:</xsl:text>
  <xsl:text>&#10;              keystore: "</xsl:text><xsl:value-of select="$validationKeystore" /><xsl:text>"</xsl:text>
  <xsl:text>&#10;              label: "</xsl:text><xsl:value-of select="$validationKeyLabel" /><xsl:text>"</xsl:text>
  <xsl:text>&#10;            validationOptions:</xsl:text>
  <xsl:text>&#10;              validateArtifactRequest: </xsl:text><xsl:value-of select="fc:EntityProperty[@name='SAML2.ValidateArtifactRequest']/fim:Value" />
  <xsl:text>&#10;              validateArtifactResponse: </xsl:text><xsl:value-of select="fc:EntityProperty[@name='SAML2.ValidateArtifactResponse']/fim:Value" />
  <xsl:text>&#10;              validateAuthnRequest: </xsl:text><xsl:value-of select="fc:EntityProperty[@name='SAML2.ValidateAuthnRequest']/fim:Value" />
  <xsl:text>&#10;              validateLogoutRequest: </xsl:text><xsl:value-of select="fc:EntityProperty[@name='SAML2.ValidateLogoutRequest']/fim:Value" />
  <xsl:text>&#10;              validateLogoutResponse: </xsl:text><xsl:value-of select="fc:EntityProperty[@name='SAML2.ValidateLogoutResponse']/fim:Value" /> 
  <xsl:text>&#10;              validateNameIDManagementRequest: </xsl:text><xsl:value-of select="fc:EntityProperty[@name='SAML2.ValidateNameIDManagementRequest']/fim:Value" />
  <xsl:text>&#10;              validateNameIDManagementResponse: </xsl:text><xsl:value-of select="fc:EntityProperty[@name='SAML2.ValidateNameIDManagementResponse']/fim:Value" />
  <xsl:text>&#10;          soapSettings:</xsl:text>
  <xsl:text>&#10;            clientAuth:</xsl:text>
  <xsl:text>&#10;              method: </xsl:text>
  <xsl:choose>
    <xsl:when test="fc:EntityProperty[@name='SAML2.SoapRequestClientBasicAuth']/fim:Value = 'true'">
      <xsl:text>ba</xsl:text>
    </xsl:when>
    <xsl:when test="fc:EntityProperty[@name='SAML2.SoapRequestClientCertAuth']/fim:Value = 'true'">
      <xsl:text>cert</xsl:text>
    </xsl:when>
    <xsl:otherwise>
      <xsl:text>none</xsl:text>
    </xsl:otherwise>
  </xsl:choose>
  <xsl:text>&#10;              properties:</xsl:text>
  <xsl:text>&#10;                username: "</xsl:text><xsl:value-of select="fc:EntityProperty[@name='SAML2.SoapRequestClientBasicAuthUser']/fim:Value" /><xsl:text>"</xsl:text>
  <xsl:text>&#10;                password: "</xsl:text><xsl:value-of select="fc:EntityProperty[@name='SAML2.SoapRequestClientBasicAuthPassword']/fim:Value" /><xsl:text>"</xsl:text>
  <xsl:text>&#10;            serverCertValidation:</xsl:text>
  <xsl:text>&#10;              keystore: ""</xsl:text>
  <xsl:apply-templates select="/fc:FederationsConfiguration/fc:Entities/fc:Entity[@id=$partnerEntityRef]/fc:ProtocolEndpoints/fc:ProtocolEndpoint[@type='SAML2.ArtifactResolutionService']" />
  <xsl:apply-templates select="/fc:FederationsConfiguration/fc:Entities/fc:Entity[@id=$partnerEntityRef]/fc:ProtocolEndpoints/fc:ProtocolEndpoint[@type='SAML2.AssertionConsumerService']" />
  <xsl:apply-templates select="/fc:FederationsConfiguration/fc:Entities/fc:Entity[@id=$partnerEntityRef]/fc:ProtocolEndpoints/fc:ProtocolEndpoint[@type='SAML2.SingleSign
OnService']" />
  <xsl:apply-templates select="/fc:FederationsConfiguration/fc:Entities/fc:Entity[@id=$partnerEntityRef]/fc:ProtocolEndpoints/fc:ProtocolEndpoint[@type='SAML2.SingleLogoutService']" />
  <xsl:apply-templates select="/fc:FederationsConfiguration/fc:Entities/fc:Entity[@id=$partnerEntityRef]/fc:ProtocolEndpoints/fc:ProtocolEndpoint[@type='SAML2.ManageNameIDService']" />
 </xsl:template>

 <xsl:template name="getStateBooleanText">
  <xsl:param name="state" />
  <xsl:choose>
    <xsl:when test="$state = 'enabled'">
      <xsl:text>true</xsl:text>
    </xsl:when>
    <xsl:otherwise>
      <xsl:text>false</xsl:text>
    </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <xsl:template match="fc:EntityProperty[@name='com.tivoli.am.fim.sts.saml.2.0.assertion.attribute.types']/fim:Value">
  <xsl:text>"</xsl:text><xsl:value-of select="." /><xsl:text>"</xsl:text>
  <xsl:if test="not(position() = last())">
    <xsl:text>, </xsl:text>
  </xsl:if>
 </xsl:template>

 <xsl:template match="fc:EntityProperty[@name='SAML2.SignatureAlgorithm']">
  <xsl:choose>
    <xsl:when test="fim:Value = 'http://www.w3.org/2001/04/xmldsig-more#rsa-sha256'">
      <xsl:text>&#10;            signatureAlgorithm: "RSA-SHA256"</xsl:text>
      <xsl:text>&#10;            digestAlgorithm: "SHA256"</xsl:text>
    </xsl:when>
    <xsl:when test="fim:Value = 'http://www.w3.org/2001/04/xmldsig-more#rsa-sha512'">
      <xsl:text>&#10;            signatureAlgorithm: "RSA-SHA512"</xsl:text>
      <xsl:text>&#10;            digestAlgorithm: "SHA512"</xsl:text>
    </xsl:when>
    <xsl:otherwise>
      <xsl:text>&#10;            signatureAlgorithm: "RSA-SHA1"</xsl:text>
      <xsl:text>&#10;            digestAlgorithm: "SHA1"</xsl:text>
    </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <xsl:template match="fc:EntityProperty[@name='SAML2.EncryptionKeyTransportAlgorithm']">
  <xsl:choose>
    <xsl:when test="fim:Value = 'http://www.w3.org/2001/04/xmlenc#rsa-1_5'">
      <xsl:text>RSA-v1.5</xsl:text>
    </xsl:when>
    <xsl:otherwise>
      <xsl:text>RSA-OAEP</xsl:text>
    </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <xsl:template match="fc:EntityProperty[@name='SAML2.LogoutNotOnOrAfter']">
  <xsl:choose>
    <xsl:when test="fim:Value = '-1' or fim:Value = ''">
      <xsl:text>120</xsl:text>
    </xsl:when>
    <xsl:otherwise><xsl:value-of select="fim:Value" /></xsl:otherwise>
  </xsl:choose>
 </xsl:template>

</xsl:stylesheet>

