<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
 xmlns:stsuuser="urn:ibm:names:ITFIM:1.0:stsuuser" version="1.0" xmlns:fc="urn:ibm:names:ITFIM:1.0:Federations" xmlns:fim="urn:ibm:names:ITFIM:1.0">
 <xsl:strip-space elements="*" />
 <xsl:output method="text" encoding="utf-8" />

 <xsl:param name="fedName" />
 <xsl:param name="partnerTemplate" />
 <xsl:param name="encryptionKeystore" />
 <xsl:param name="encryptionKeyLabel" />
 <xsl:param name="signingKeystore" />
 <xsl:param name="signingKeyLabel" />
 <xsl:param name="validationKeystore" />
 <xsl:param name="validationKeyLabel" />
 <xsl:param name="reverseProxyInstance" />
 <xsl:param name="aacUsername" />
 <xsl:param name="aacPwd" />

 <xsl:template match="*">
   <xsl:apply-templates select="/fc:FederationsConfiguration/fc:EntityGroups/fc:EntityGroup[fc:DisplayName = $fedName]" />
 </xsl:template>

 <xsl:template match="fc:EntityGroup" >
  <xsl:variable name="selfEntityRef"><xsl:value-of select="fc:Self/@entityRef" /></xsl:variable>
  <xsl:text>- name: Configure Federation Migrated from FIM</xsl:text>
  <xsl:text>&#10;  hosts: all</xsl:text>
  <xsl:text>&#10;  connection: local</xsl:text>
  <xsl:text>&#10;  roles:</xsl:text>
  <xsl:text>&#10;      - role: set_federation</xsl:text>
  <xsl:text>&#10;        tags: ["federation", "migrate", "quickconnector"]</xsl:text>
  <xsl:text>&#10;        set_federation_name: "</xsl:text><xsl:value-of select="fc:DisplayName" /><xsl:text>"</xsl:text>
  <xsl:text>&#10;        set_federation_protocol: "</xsl:text><xsl:value-of select="fc:Self/fc:EntityProperty[@name='FED_PROT']/fim:Value" /><xsl:text>"</xsl:text>
  <xsl:text>&#10;        set_federation_role: "</xsl:text><xsl:value-of select="/fc:FederationsConfiguration/fc:Entities/fc:Entity[@id=$selfEntityRef]/@role" /><xsl:text>"</xsl:text>
  <xsl:text>&#10;        set_federation_templateName: "QuickConnect"</xsl:text>
  <xsl:text>&#10;        set_federation_configuration:</xsl:text>
  <xsl:text>&#10;          encryptionSettings:</xsl:text>
  <xsl:text>&#10;            decryptionKeyIdentifier:</xsl:text>
  <xsl:text>&#10;              keystore: "</xsl:text><xsl:value-of select="$encryptionKeystore" /><xsl:text>"</xsl:text>
  <xsl:text>&#10;              label: "</xsl:text><xsl:value-of select="$encryptionKeyLabel" /><xsl:text>"</xsl:text>
  <xsl:text>&#10;          pointOfContactUrl: "</xsl:text><xsl:value-of select="fc:Self/fc:EntityProperty[@name='SPS.SelfPathToSPS']/fim:Value" /><xsl:text>"</xsl:text>
  <xsl:text>&#10;          signatureSettings:</xsl:text>
  <xsl:text>&#10;            signingKeyIdentifier:</xsl:text>
  <xsl:text>&#10;              keystore: "</xsl:text><xsl:value-of select="$signingKeystore" /><xsl:text>"</xsl:text>
  <xsl:text>&#10;              label: "</xsl:text><xsl:value-of select="$signingKeyLabel" /><xsl:text>"</xsl:text>
  <xsl:text>&#10;</xsl:text>
  <xsl:text>&#10;      - role: config_reverseproxy_federation</xsl:text>
  <xsl:text>&#10;        tags: ["federation", "migrate", "reverseproxy", "config"]</xsl:text>
  <xsl:text>&#10;        config_reverseproxy_federation_name: "</xsl:text><xsl:value-of select="$fedName" /><xsl:text>"</xsl:text>
  <xsl:text>&#10;        config_reverseproxy_federation_instance_id: "</xsl:text><xsl:value-of select="$reverseProxyInstance" /><xsl:text>"</xsl:text>
  <xsl:text>&#10;        config_reverseproxy_federation_username: "</xsl:text><xsl:value-of select="$aacUsername" /><xsl:text>"</xsl:text>
  <xsl:text>&#10;        config_reverseproxy_federation_password: "</xsl:text><xsl:value-of select="$aacPwd" /><xsl:text>"</xsl:text>
  <xsl:text>&#10;</xsl:text>
   <xsl:apply-templates select="fc:Partners/fc:Partner" />
 </xsl:template>

 <xsl:template match="fc:ProtocolEndpoint[@type='SAML2.ArtifactResolutionService']">
  <xsl:if test="position() = 1">
    <xsl:text>&#10;          artifactResolutionService: [ </xsl:text>
  </xsl:if>
  <xsl:text>{ </xsl:text>
  <xsl:apply-templates select="fc:EndpointProperties/fim:Parameter[@name='Binding']" />
  <xsl:apply-templates select="fc:EndpointProperties/fim:Parameter[@name='IsDefault']" />
  <xsl:apply-templates select="fc:EndpointProperties/fim:Parameter[@name='Index']" />
  <xsl:text>, "url": "</xsl:text><xsl:value-of select="@endpoint" /><xsl:text>"</xsl:text>
  <xsl:text> }</xsl:text>
  <xsl:choose>
   <xsl:when test="position() = last()">
     <xsl:text> ]</xsl:text>
   </xsl:when>
   <xsl:otherwise>
     <xsl:text>, </xsl:text>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <xsl:template match="fc:ProtocolEndpoint[@type='SAML2.AssertionConsumerService']">
  <xsl:if test="position() = 1">
    <xsl:text>&#10;          assertionConsumerService: [ </xsl:text>
  </xsl:if>
  <xsl:text>{ </xsl:text>
  <xsl:apply-templates select="fc:EndpointProperties/fim:Parameter[@name='Binding']" />
  <xsl:apply-templates select="fc:EndpointProperties/fim:Parameter[@name='IsDefault']" />
  <xsl:apply-templates select="fc:EndpointProperties/fim:Parameter[@name='Index']" />
  <xsl:text>, "url": "</xsl:text><xsl:value-of select="@endpoint" /><xsl:text>"</xsl:text>
  <xsl:text> }</xsl:text>
  <xsl:choose>
   <xsl:when test="position() = last()">
     <xsl:text> ]</xsl:text>
   </xsl:when>
   <xsl:otherwise>
     <xsl:text>, </xsl:text>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <xsl:template match="fc:ProtocolEndpoint[@type='SAML2.SingleSignOnService']">
  <xsl:if test="position() = 1">
    <xsl:text>&#10;          singleSignOnService: [ </xsl:text>
  </xsl:if>
  <xsl:text>{ </xsl:text>
  <xsl:apply-templates select="fc:EndpointProperties/fim:Parameter[@name='Binding']" />
  <xsl:text>, "url": "</xsl:text><xsl:value-of select="@endpoint" /><xsl:text>"</xsl:text>
  <xsl:text> }</xsl:text>
  <xsl:choose>
   <xsl:when test="position() = last()">
     <xsl:text> ]</xsl:text>
   </xsl:when>
   <xsl:otherwise>
     <xsl:text>, </xsl:text>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <xsl:template match="fc:ProtocolEndpoint[@type='SAML2.SingleLogoutService']">
  <xsl:if test="position() = 1">
    <xsl:text>&#10;          singleLogoutService: [ </xsl:text>
  </xsl:if>
  <xsl:text>{ </xsl:text>
  <xsl:apply-templates select="fc:EndpointProperties/fim:Parameter[@name='Binding']" />
  <xsl:text>, "url": "</xsl:text><xsl:value-of select="@endpoint" /><xsl:text>"</xsl:text>
  <xsl:text> }</xsl:text>
  <xsl:choose>
   <xsl:when test="position() = last()">
     <xsl:text> ]</xsl:text>
   </xsl:when>
   <xsl:otherwise>
     <xsl:text>, </xsl:text>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <xsl:template match="fc:ProtocolEndpoint[@type='SAML2.ManageNameIDService']">
  <xsl:if test="position() = 1">
    <xsl:text>&#10;          manageNameIDService: [ </xsl:text>
  </xsl:if>
  <xsl:text>{ </xsl:text>
  <xsl:apply-templates select="fc:EndpointProperties/fim:Parameter[@name='Binding']" />
  <xsl:text>, "url": "</xsl:text><xsl:value-of select="@endpoint" /><xsl:text>"</xsl:text>
  <xsl:text> }</xsl:text>
  <xsl:choose>
   <xsl:when test="position() = last()">
     <xsl:text> ]</xsl:text>
   </xsl:when>
   <xsl:otherwise>
     <xsl:text>, </xsl:text>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <xsl:template match="fim:Parameter[@name='Binding']">
  <xsl:text>"binding": "</xsl:text>
    <xsl:choose>
    <xsl:when test="fim:Value = 'urn:oasis:names:tc:SAML:2.0:bindings:SOAP'">
      <xsl:text>soap"</xsl:text>
    </xsl:when>
    <xsl:when test="fim:Value = 'urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Artifact'">
      <xsl:text>artifact"</xsl:text>
    </xsl:when>
    <xsl:when test="fim:Value = 'urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST'">
      <xsl:text>post"</xsl:text>
    </xsl:when>
    <xsl:when test="fim:Value = 'urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect'">
      <xsl:text>redirect"</xsl:text>
    </xsl:when>
    <xsl:otherwise>
      <xsl:text>"</xsl:text>
    </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <xsl:template match="fim:Parameter[@name='IsDefault']">
   <xsl:text>, "default": </xsl:text><xsl:value-of select="fim:Value" />
 </xsl:template>

 <xsl:template match="fim:Parameter[@name='Index']">
   <xsl:text>, "index": </xsl:text><xsl:value-of select="fim:Value" />
 </xsl:template>

 <xsl:template match="fc:Partner">
  <xsl:variable name="partnerEntityRef"><xsl:value-of select="@entityRef" /></xsl:variable>
  <xsl:text>&#10;      - role: set_partner</xsl:text>
  <xsl:text>&#10;        tags: ["federation", "partner", "migrate", "quickconnector"]</xsl:text>
  <xsl:text>&#10;        set_partner_federation_name: "</xsl:text><xsl:value-of select="$fedName" /><xsl:text>"</xsl:text>
  <xsl:text>&#10;        set_partner_partner_name: "</xsl:text><xsl:value-of select="/fc:FederationsConfiguration/fc:Entities/fc:Entity[@id=$partnerEntityRef]/fc:DisplayName" /><xsl:text>"</xsl:text>
  <xsl:text>&#10;        set_partner_enabled: </xsl:text><xsl:call-template name="getStateBooleanText"><xsl:with-param name="state" select="@state" /></xsl:call-template>
  <xsl:text>&#10;        set_partner_role: "</xsl:text><xsl:value-of select="/fc:FederationsConfiguration/fc:Entities/fc:Entity[@id=$partnerEntityRef]/@role" /><xsl:text>"</xsl:text>
  <xsl:text>&#10;        set_partner_templateName: "</xsl:text><xsl:value-of select="$partnerTemplate" /><xsl:text>"</xsl:text>
  <xsl:text>&#10;        set_partner_configuration:</xsl:text>
  <xsl:text>&#10;          attributeMapping:</xsl:text>
  <xsl:text>&#10;            map: []</xsl:text>
  <xsl:text>&#10;          encryptionSettings:</xsl:text>
  <xsl:text>&#10;            encryptionOptions:</xsl:text>
  <xsl:text>&#10;              encryptAssertion: </xsl:text><xsl:value-of select="fc:EntityProperty[@name='SAML2.EncryptAssertions']" />
  <xsl:text>&#10;          providerId: "</xsl:text><xsl:value-of select="/fc:FederationsConfiguration/fc:Entities/fc:Entity[@id=$partnerEntityRef]/@protocolId" /><xsl:text>"</xsl:text>
  <xsl:text>&#10;          signatureSettings:</xsl:text>
  <xsl:text>&#10;            validationKeyIdentifier:</xsl:text>
  <xsl:text>&#10;              keystore: "</xsl:text><xsl:value-of select="$validationKeystore" /><xsl:text>"</xsl:text>
  <xsl:text>&#10;              label: "</xsl:text><xsl:value-of select="$validationKeyLabel" /><xsl:text>"</xsl:text>
  <xsl:text>&#10;            validationOptions:</xsl:text>
  <xsl:text>&#10;              validateAuthnRequest: </xsl:text><xsl:value-of select="fc:EntityProperty[@name='SAML2.ValidateAuthnRequest']/fim:Value" />
  <xsl:apply-templates select="/fc:FederationsConfiguration/fc:Entities/fc:Entity[@id=$partnerEntityRef]/fc:ProtocolEndpoints/fc:ProtocolEndpoint[@type='SAML2.ArtifactResolutionService']" />
  <xsl:apply-templates select="/fc:FederationsConfiguration/fc:Entities/fc:Entity[@id=$partnerEntityRef]/fc:ProtocolEndpoints/fc:ProtocolEndpoint[@type='SAML2.AssertionConsumerService']" />
  <xsl:apply-templates select="/fc:FederationsConfiguration/fc:Entities/fc:Entity[@id=$partnerEntityRef]/fc:ProtocolEndpoints/fc:ProtocolEndpoint[@type='SAML2.SingleSign
OnService']" />
  <xsl:apply-templates select="/fc:FederationsConfiguration/fc:Entities/fc:Entity[@id=$partnerEntityRef]/fc:ProtocolEndpoints/fc:ProtocolEndpoint[@type='SAML2.SingleLogoutService']" />
  <xsl:apply-templates select="/fc:FederationsConfiguration/fc:Entities/fc:Entity[@id=$partnerEntityRef]/fc:ProtocolEndpoints/fc:ProtocolEndpoint[@type='SAML2.ManageNameIDService']" />
 </xsl:template>

 <xsl:template name="getStateBooleanText">
  <xsl:param name="state" />
  <xsl:choose>
    <xsl:when test="$state = 'enabled'">
      <xsl:text>true</xsl:text>
    </xsl:when>
    <xsl:otherwise>
      <xsl:text>false</xsl:text>
    </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

</xsl:stylesheet>

